sequencetools.count_length_two_runs_in_sequence
===============================================

.. autofunction:: abjad.tools.sequencetools.count_length_two_runs_in_sequence.count_length_two_runs_in_sequence
